==> easyviper.core.api-1.0.1-sources.jar: com/ebmwebsourcing/easyviper/core/api/engine/Process.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.api.engine;

import java.util.Map;

import org.objectweb.fractal.fraclet.annotations.Interface;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.monitoring.Monitor;
import com.ebmwebsourcing.easyviper.core.api.env.ExternalContext;
import com.ebmwebsourcing.easyviper.core.api.model.registry.ProcessKey;
import com.ebmwebsourcing.easyviper.core.api.soa.message.InternalMessage;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@Interface(name = "process")
public interface Process extends Scope {

	public enum State {
		PROCESS_INACTIVE, PROCESS_ACTIVE, PROCESS_ENDED, PROCESS_UNSTABLE
	};
	
	void run() throws CoreException;

	Execution createParentExecution() throws CoreException;

	Map<String, Execution> getConcernedExecutions(InternalMessage<?> message)
			throws CoreException;

	Engine getEngine() throws CoreException;

	ProcessKey getProcessKey();

	void setProcessKey(ProcessKey key);

	ExternalContext getExternalContext();

	void setExternalContext(ExternalContext context);
	
	Monitor getMonitor();
	
	State getState();
	
	void setState(State state);
}

==> easyviper.core.api-1.1-sources.jar: com/ebmwebsourcing/easyviper/core/api/engine/Process.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.api.engine;

import java.util.List;
import java.util.Map;

import org.objectweb.fractal.fraclet.annotations.Interface;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.monitoring.Monitor;
import com.ebmwebsourcing.easyviper.core.api.env.ExternalContext;
import com.ebmwebsourcing.easyviper.core.api.model.registry.ProcessKey;
import com.ebmwebsourcing.easyviper.core.api.soa.message.InternalMessage;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
@Interface(name = "process")
public interface Process extends Scope {

	public enum State {
		PROCESS_INACTIVE, PROCESS_ACTIVE, PROCESS_ENDED, PROCESS_UNSTABLE
	};
	
	void run() throws CoreException;

	Execution createParentExecution() throws CoreException;

	Map<String, Execution> getSuspendedExecutions() throws CoreException;

	Engine getEngine() throws CoreException;

//	ProcessKey getProcessKey();
//
//	void setProcessKey(ProcessKey key);

	ExternalContext getExternalContext();

	void setExternalContext(ExternalContext context);
	
	Monitor getMonitor();
	
	State getState();
	
	void setState(State state);
	
	void setProcessKeys(List<ProcessKey> keys);
	
	List<ProcessKey> getProcessKeys();
}
